﻿using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Serialize;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _8956
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.DecimalDegree;

            LayerOverlay layerOverlay = new LayerOverlay();
            ShapeFileFeatureLayer shapeFileLayer = new ShapeFileFeatureLayer(@"..\..\AppData\states.shp");
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = WorldStreetsAreaStyles.Military();
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layerOverlay.Layers.Add(shapeFileLayer);
            map.Overlays.Add(layerOverlay);
            map.MouseMove += Map_MouseMove;

            shapeFileLayer.Open();
            map.CurrentExtent = shapeFileLayer.GetBoundingBox();
            map.Refresh();
        }

        private void Map_MouseMove(object sender, System.Windows.Input.MouseEventArgs e)
        {
            Point currentPoint = e.GetPosition(map);
            PointShape worldPoint = ExtentHelper.ToWorldCoordinate(map.CurrentExtent, new ScreenPointF((float)currentPoint.X, (float)currentPoint.Y), (float)map.ActualWidth, (float)map.ActualHeight);

            RectangleShape rect = map.CurrentExtent;
            rect.ScaleDown(10);
            if (!rect.Contains(worldPoint))
            {
                if (worldPoint.X < rect.UpperLeftPoint.X)
                {
                    map.Pan(PanDirection.Left, 2);
                    return;
                }

                if (worldPoint.X > rect.LowerRightPoint.X)
                {
                    map.Pan(PanDirection.Right, 2);
                    return;
                }

                if (worldPoint.Y < rect.LowerRightPoint.Y)
                {
                    map.Pan(PanDirection.Down, 2);
                    return;
                }

                if (worldPoint.Y > rect.UpperLeftPoint.Y)
                {
                    map.Pan(PanDirection.Up, 2);
                    return;
                }
            }
        }
    }
}
